.. _whatsnew_1020:

v1.0.2 (July 5, 2019)
=====================

Some bug fixes and enhancements. Now the PVEngine can run simulations using a "fast-mode" with observed speed gain of around 30% and accuracy drop of around 4% compared to the full mode.


* Update python dependencies and test requirements (#50)
* Added a Tolerance for direct shading detection to cast_shadow function (#51)
* Fix broken tests from #51 & check circleci (#52)
* Implement a fast simulation mode in PVEngine (#53)
* Build sphinx docs into CircleCI artifacts (#54)
* Make engine more robust to bad weather data (#55)


Contributors
------------

* Marc Anoma (:ghuser:`anomam`)
* Thomas Capelle (:ghuser:`tcapelle`)
